@@ -55,6 +55,7 @@ from lfmaptools.utilities import (_nice_round,
                                   csv_active_cols,
                                   csv_num_cols,
                                   _decompress_gz)
+from lfmaptools.netcdf_utils import nc2np, nc_max, nc_min
 from lfmaptools.geotools import LatLon_TM_polygonize, LatLon_TM
 from lfmaptools.epsg_defs import webmerc, wgs84
 from lfmaptools.mapping import add_stamen_basemap
@@ -725,8 +726,6 @@ class LaharFlowData(object):
         # cols = csv_active_cols(LaharFlowFile)
         # data = np.genfromtxt(LaharFlowFile, delimiter=',', names=True, usecols=cols)
         data = self._get_data(filename)
-        print(filename)
-        print(data)
         
         extra_cols = ['tile', 'x_distance', 'y_distance', 'latitude', 'longitude']
         if var is None:
@@ -960,8 +959,6 @@ class LaharFlowData(object):
     def _get_max_bed_evolution(self):
         last_outfile = int(self.get_snapshot_files()[-1])
 
-        print(last_outfile)
-
         data = self.raster(last_outfile, var=['elevation_change'])
 
         bt = data['elevation_change'].values
@@ -994,11 +991,12 @@ class LaharFlowData(object):
     def _get_max_depth(self):
         
         if 'Maximums.nc' in self.nc_files:
-            d = self._get_data('Maximums.nc')
-            if d is not None:
-                self.MaxDepth = d['maximum_depth'].max()
-            else:
-                self.MaxDepth = None
+            LaharFlowFile = self._extract_file('Maximums.nc')
+            try:
+                m = nc_max(LaharFlowFile, 'maximum_depth')
+                self.MaxDepth = m['maximum_depth']
+            except:
+                self.MaxDepth = None            
             return
         elif 'MaxHeights.txt' in self.txt_files:
             _, _, h = self._get_data_column('MaxHeights.txt', 5)
@@ -1030,11 +1028,12 @@ class LaharFlowData(object):
     def _get_max_speed(self):
         
         if 'Maximums.nc' in self.nc_files:
-            d = self._get_data('Maximums.nc')
-            if d is not None:
-                self.MaxSpeed = d['maximum_speed'].max()
-            else:
-                self.MaxSpeed = None
+            LaharFlowFile = self._extract_file('Maximums.nc')
+            try:
+                m = nc_max(LaharFlowFile, 'maximum_speed')
+                self.MaxSpeed = m['maximum_speed']
+            except:
+                self.MaxSpeed = None            
             return
         elif 'MaxSpeeds.txt' in self.txt_files:
             _, _, spd = self._get_data_column('MaxSpeeds.txt', 5)
